@@ -42,7 +42,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
 
 class ListHumanLoopsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_a2i_runtime/paginators.html#listhumanloopspaginator)
     """
 
@@ -50,12 +50,12 @@ class ListHumanLoopsPaginator(Boto3Paginator):
         self,
         *,
         FlowDefinitionArn: str,
-        CreationTimeAfter: Union[datetime, str] = None,
-        CreationTimeBefore: Union[datetime, str] = None,
-        SortOrder: SortOrderType = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        CreationTimeAfter: Union[datetime, str] = ...,
+        CreationTimeBefore: Union[datetime, str] = ...,
+        SortOrder: SortOrderType = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListHumanLoopsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_a2i_runtime/paginators.html#listhumanloopspaginator)
         """
